<?php
error_reporting(E_ALL);
ini_set('display_errors', 1); 
ini_set('display_startup_errors', 1);

require_once 'config.inc.php';
require_once 'lab14a-test03-helpers.inc.php';
require_once 'lab14a-db-classes.inc.php';


try {
  $conn = DatabaseHelper::createConnection(array(DBCONNSTRING, DBUSER, DBPASS));
  $paintGateway = new PaintingDB($conn);
  $galleryGateway = new GalleryDB($conn);
  $galleries = $galleryGateway->getAll();

  if (isset($_GET['museum']) && $_GET['museum'] > 0) {      
     $paintings = $paintGateway->getAllForGallery($_GET['museum'] );
  } else {
     $paintings = $paintGateway->getTop20();
  }
} catch (Exception $e) { die( $e->getMessage() ); }

?>
<!DOCTYPE html>
<html lang=en>
<head>
    <title>Lab 14</title>
    <meta charset=utf-8>
    <link href='http://fonts.googleapis.com/css?family=Merriweather' rel='stylesheet' type='text/css'>
    <link href='http://fonts.googleapis.com/css?family=Open+Sans' rel='stylesheet' type='text/css'>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/semantic-ui/2.4.1/semantic.min.css" rel="stylesheet">
</head>
<body >
    
<main class="ui segment doubling stackable grid container">

    <section class="four wide column">
        <form class="ui form" method="get" action="<?=$_SERVER['REQUEST_URI']?>">
          <h3 class="ui dividing header">Filters</h3>

          <div class="field">
            <label>Museum</label>
            <select class="ui fluid dropdown" name="museum">
                <option value='0'>Select Museum</option>  
                <?php  
                   outputOptions($galleries, 'GalleryID', 'GalleryName');
                ?>
            </select>
          </div>   
          <button class="small ui orange button" type="submit">
              <i class="filter icon"></i> Filter 
          </button>    

        </form>
    </section>
    

    <section class="twelve wide column">
        <h1 class="ui header">Paintings</h1>
        <ul class="ui divided items" id="paintingsList">
            
          <?php  foreach ($paintings as $work) { ?>

          <li class="item">
            <a class="ui small image" href="single-painting.php?id=<?= $work['PaintingID']; ?>"><img src="images/art/works/square-medium/<?= $work['ImageFileName']; ?>.jpg"></a>
            <div class="content">
              <a class="header" href="single-painting.php?id=<?= $work['PaintingID']; ?>"><?= utf8_encode($work['Title']); ?></a>
              <div class="meta"><span class="cinema"><?= makeArtistName($work['FirstName'],$work['LastName']); ?></span></div>        
              <div class="description">
                <p><?php echo utf8_encode($work['Excerpt']); ?></p>
              </div>
              <div class="meta">     
                  <strong><?= $work['YearOfWork'] ?></strong>        
              </div>        
            </div>      
          </li>
            
          <?php } ?>



        </ul>        
    </section>  
    
</main>    
<footer class="ui black inverted segment">
  <div class="ui container">&Copy 2021 Fundamentals of Web Development</div>
</footer>
</body>
</html>